#ifndef _STATISTIC_HH_
#define _STATISTIC_HH_

#include "sys_time.hh"

struct pair
{
  double X;
  double Y;
};

class Table
{
private:
  pair*   tables_array[32];
  int     tables_pow2dim;
  int     tables_dim;
public:
  Table(unsigned int);
  Table(Table&);
  ~Table();
  pair* operator[](unsigned int);
};

class Statistic
{
private:
  Table           data;
  unsigned int    elements;
  char            name[128];
  static sys_time start_time;
public:
  Statistic(char* =NULL);
  Statistic(Statistic&);
  ~Statistic();
  void WriteToFile(char*);
  void ReadFromFile(char*);
  unsigned int Elements();
  const char* Name();
  void Add();
  void Add(double);
  void Read(unsigned int,double*,double*);
  double Max();
  double Min();
  double Sample_mean();
  double Sample_mean_window(double,double);
  //void Delta();
  friend Statistic Delta(Statistic&);
  friend Statistic Distribution(Statistic&);
  friend Statistic Probability(Statistic&);
  friend Statistic operator-(Statistic&,Statistic&);
  //friend void Frequency(Statistic&,Statistic&,double*,unsigned int);
};

class Statistic_Manager
{
private:
  unsigned int  elements;
  const int     max_stat_number = 32;
  Statistic*    pstat_array[32];
  char          stat_name_array[32][128];
public:
  Statistic_Manager();
  ~Statistic_Manager();
  Statistic* QueryNewStat(char*);
  Statistic* QueryByName(char*);
};

#endif


  
